/**********************
 * Stanford Law Review Paper Appendix Table 6B
 * The Effect of Shall-Issue Laws using Lott's Time Trend Specification for Selected Years
 * 1977-1996
 **********************



#delimit;
set more off;
set mem 160000;
log using "AppendixTable6.B.log", replace;
set matsize 700;
use "..\Lott", clear;

sort state;
merge state using "..\regions";
tabulate _merge;
drop if _merge==1;
drop if state==.;
drop if region==.;
drop if YEAR==.;
gen str3 yr_reg=string(YEAR)+string(region);
tabulate yr_reg, gen(yr_rg);
gen RPCRPO93=RPCRPO;
replace RPCRPO93=0 if YEAR<93;
gen ttrend=YEAR-76;
replace ttrend=0 if yradopt<77 | yradopt>97;


/*PANEL B2*/
gen aftr96=SHTRDAFT;
replace aftr96=aftr if yradopt>91 & yradopt<96;
gen befr96=SHTRDBEF;
replace befr96=befr if yradopt>91 & yradopt<96;

areg lvio befr96 aftr96 AOVIOICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust; 
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, replace noparen nolabel coefastr 3aster;

areg lmur befr96 aftr96 AOMURICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg lrap befr96 aftr96 AORAPICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg laga befr96 aftr96 AOAGAICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg lrob befr96 aftr96 AOROBICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg lpro befr96 aftr96 AOPROICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg laut befr96 aftr96 AOAUTICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg lbur befr96 aftr96 AOBURICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

areg  llar befr96 aftr96 AOLARICP DENSITY RPCPI RPCUI RPCIM  POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B2.xls, append noparen nolabel coefastr 3aster;

/*PANEL B3*/
drop aftr96 befr96;
gen aftr96=aftr;
replace aftr96=0 if yradopt==96;
gen befr96=befr;
replace befr96=0 if yradopt==96;

areg lvio befr96 aftr96 AOVIOICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96  yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust; 
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, replace noparen nolabel coefastr 3aster;

areg lmur befr96 aftr96 AOMURICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg lrap befr96 aftr96 AORAPICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg laga befr96 aftr96 AOAGAICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg lrob befr96 aftr96 AOROBICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg lpro befr96 aftr96 AOPROICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg laut befr96 aftr96 AOAUTICP DENSITY RPCPI RPCUI RPCIM POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg  lbur befr96 aftr96 AOBURICP DENSITY RPCPI RPCUI RPCIM  POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

areg  llar befr96 aftr96 AOLARICP DENSITY RPCPI RPCUI RPCIM  POPC RPCRPO RPCRPO93 PB* PW* PN* IYEAR_78-iyear_96 yr_rg2-yr_rg100
[aweight=POPC], absorb(COUNTY) robust;
test aftr96=befr96;

outreg befr96 aftr96 using AppendixTable6.B3.xls, append noparen nolabel coefastr 3aster;

log close;