/****************
 * Stanford Law Review Paper Table 2a.3 and 2b.3
 * Zheng's Dataset 
 * Vernick's coding
 * Hybrid Model (without and with state trends)
 * 1977-1999
 ********************/

clear
set memory 200000
set matsize 300
set more off
capture log close
log using "Table2ab.3.log", replace
#delimit ;
use "wentong7799_vernick.dta";

/** Read in data
 * state, year (1960), fipsstat, pop (population), pop1(once-lagged
 * population), black (black population in 1000s), metro (metropolitan 
 * population in 1000s), p15t17 (population of ages 15 to 17 in 1000s), 
 * p18t24 (population of ages 18 to 24 in 1000s), p25t34 (population of
 * ages 25 to 34 in 1000s), income (per capita income, nominal), price
 * (price deflator), unemp (unemployment rate), poverty (percent of 
 * persons below poverty line), police (number of sworn police officers),
 * police1 (number of sworn police officers, once-lagged), prisoners 
 * (prison population), prisoners1 (prison population, once-lagged),
 * alcohol (alcohol consumption, in 1000s of gallons), governor (1 if 
 * democrat, 2 if repulican, 3 if independent, 4 if other), violent 
 * (violent crime, per 100,000), murder (per 100,000), rape (per 100,000),
 * assault (aggravated assault, per 100,000), robbery (per 100,000),
 * property (per 100,000), burglary (per 100,000), larceny (per 100,000),
 * auto (auto vehicle theft, per 100,000)
 **/

/** Generate crime variables **/

gen lvio=ln(violent);
gen lmur=ln(murder);
gen lrap=ln(rape);
gen laga=ln(assault);
gen lrob=ln(robbery);
gen lpro=ln(property);
gen lbur=ln(burglary);
gen llar=ln(larceny);
gen laut=ln(auto);

/** Generate other variables **/

gen black_per=black*1000/pop*100;
gen metro_per=metro*1000/pop*100;
gen age1_per=p15t17*1000/pop*100;
gen age2_per=p18t24*1000/pop*100;
gen age3_per=p25t34*1000/pop*100;
gen rincome=income*(100/price);
gen police_per1=police1/pop1*100000;
gen prison_per1=prisoners1/pop1*100000;
gen alcohol_per=alcohol*1000/pop;

/**Generate year dummies **/

gen yr77=0;
gen yr78=0;
gen yr79=0;
gen yr80=0;
gen yr81=0;
gen yr82=0;
gen yr83=0;
gen yr84=0;
gen yr85=0;
gen yr86=0;
gen yr87=0;
gen yr88=0;
gen yr89=0;
gen yr90=0;
gen yr91=0;
gen yr92=0;
gen yr93=0;
gen yr94=0;
gen yr95=0;
gen yr96=0;
gen yr97=0;
gen yr98=0;
gen yr99=0;

replace yr77=1 if year==1977;
replace yr78=1 if year==1978;
replace yr79=1 if year==1979;
replace yr80=1 if year==1980;
replace yr81=1 if year==1981;
replace yr82=1 if year==1982;
replace yr83=1 if year==1983;
replace yr84=1 if year==1984;
replace yr85=1 if year==1985;
replace yr86=1 if year==1986;
replace yr87=1 if year==1987;
replace yr88=1 if year==1988;
replace yr89=1 if year==1989;
replace yr90=1 if year==1990;
replace yr91=1 if year==1991;
replace yr92=1 if year==1992;
replace yr93=1 if year==1993;
replace yr94=1 if year==1994;
replace yr95=1 if year==1995;
replace yr96=1 if year==1996;
replace yr97=1 if year==1997;
replace yr98=1 if year==1998;
replace yr99=1 if year==1999;

/** Generate state-specific time trend **/

gen ttt=year-1976;
gen byte AK=fipsstat== 2;
gen byte AL=fipsstat== 1;
gen byte AZ=fipsstat== 4;
gen byte AR=fipsstat== 5;
gen byte CA=fipsstat== 6;
gen byte CO=fipsstat== 8;
gen byte CT=fipsstat== 9;
gen byte DC=fipsstat== 11;
gen byte DE=fipsstat== 10;
gen byte FL=fipsstat== 12;
gen byte GA=fipsstat== 13;
gen byte HI=fipsstat== 15;
gen byte IA=fipsstat== 19;
gen byte ID=fipsstat== 16;
gen byte IL=fipsstat== 17;
gen byte IN=fipsstat== 18;
gen byte KS=fipsstat== 20;
gen byte KY=fipsstat== 21;
gen byte LA=fipsstat== 22;
gen byte MA=fipsstat== 25;
gen byte MD=fipsstat== 24;
gen byte ME=fipsstat== 23;
gen byte MI=fipsstat== 26;
gen byte MN=fipsstat== 27;
gen byte MO=fipsstat== 29;
gen byte MS=fipsstat== 28;
gen byte MT=fipsstat== 30;
gen byte NC=fipsstat== 37;
gen byte ND=fipsstat== 38;
gen byte NE=fipsstat== 31;
gen byte NH=fipsstat== 33;
gen byte NJ=fipsstat== 34;
gen byte NM=fipsstat== 35;
gen byte NV=fipsstat== 32;
gen byte NY=fipsstat== 36;
gen byte OH=fipsstat== 39;
gen byte OK=fipsstat== 40;
gen byte OR=fipsstat== 41;
gen byte PA=fipsstat== 42;
gen byte RI=fipsstat== 44;
gen byte SC=fipsstat== 45;
gen byte SD=fipsstat== 46;
gen byte TN=fipsstat== 47;
gen byte TX=fipsstat== 48;
gen byte UT=fipsstat== 49;
gen byte VA=fipsstat== 51;
gen byte VT=fipsstat== 50;
gen byte WA=fipsstat== 53;
gen byte WI=fipsstat== 55;
gen byte WV=fipsstat== 54;
gen byte WY=fipsstat== 56;


gen tttAK =ttt*AK;
gen tttAL =ttt*AL;
gen tttAZ =ttt*AZ;
gen tttAR =ttt*AR;
gen tttCA =ttt*CA;
gen tttCO =ttt*CO;
gen tttCT =ttt*CT;
gen tttDC =ttt*DC;
gen tttDE =ttt*DE;
gen tttFL =ttt*FL;
gen tttGA =ttt*GA;
gen tttHI =ttt*HI;
gen tttIA =ttt*IA;
gen tttID =ttt*ID;
gen tttIL =ttt*IL;
gen tttIN =ttt*IN;
gen tttKS =ttt*KS;
gen tttKY =ttt*KY;
gen tttLA =ttt*LA;
gen tttMA =ttt*MA;
gen tttMD =ttt*MD;
gen tttME =ttt*ME;
gen tttMI =ttt*MI;
gen tttMN =ttt*MN;
gen tttMO =ttt*MO;
gen tttMS =ttt*MS;
gen tttMT =ttt*MT;
gen tttNC =ttt*NC;
gen tttND =ttt*ND;
gen tttNE =ttt*NE;
gen tttNH =ttt*NH;
gen tttNJ =ttt*NJ;
gen tttNM =ttt*NM;
gen tttNV =ttt*NV;
gen tttNY =ttt*NY;
gen tttOH =ttt*OH;
gen tttOK =ttt*OK;
gen tttOR =ttt*OR;
gen tttPA =ttt*PA;
gen tttRI =ttt*RI;
gen tttSC =ttt*SC;
gen tttSD =ttt*SD;
gen tttTN =ttt*TN;
gen tttTX =ttt*TX;
gen tttUT =ttt*UT;
gen tttVA =ttt*VA;
gen tttVT =ttt*VT;
gen tttWA =ttt*WA;
gen tttWI =ttt*WI;
gen tttWV =ttt*WV;
gen tttWY =ttt*WY;

/* Generate shall law dummies */

replace shalll=0;
replace shalll=1 if year-1900>yradopt & yradopt~=0;
replace shalll=0 if yradopt<77;

gen ttt1=year-1976 if yradopt>77;
replace ttt1=0 if ttt1==.;
gen aftr=year-1900-yradopt if year>1900+yradopt & yradopt>77;
replace aftr=0 if aftr==.;

/*Crime	Murder	Rape	Assault	Robbery	Crime	Theft	Burglary	Larceny	*/

areg  lvio shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2a.3.xls, replace noparen nolabel coefastr se 3aster;

areg  lmur shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrap shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  laga shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrob shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  lpro shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  laut shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  lbur shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;

areg  llar shalll aftr ttt1 pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 [aweight=pop], absorb(fipsstat) robust;
outreg shalll aftr using Table2a.3.xls, append noparen nolabel coefastr se 3aster;



/** Regressions with state-specific trends **/

drop ttt;
drop ttt1;

areg  lvio 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, replace noparen nolabel coefastr se 3aster;

areg  lmur 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrap 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  laga 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrob 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lpro 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  laut 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lbur 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;

areg  llar 
shalll aftr pop black_per metro_per age1_per age2_per
age3_per rincome unemp poverty police_per1 prison_per1 alcohol_per 
yr78-yr99 ttt* [aweight=pop], absorb(fipsstat) robust; 
outreg shalll aftr using Table2b.3.xls, append noparen nolabel coefastr se 3aster;



log close;
