/********************
 * Stanford Law Review paper Table 3b.3
 * State Data
 * Hybrid Model Controlling for State Trends
 * Vernick's coding and incarceration rate
 * 1977-1999
 ********************/

clear
set more off
set mem 40m
set mat 800
use "..\FINAL DATASET.dta", clear
log using "Table3b.3.log", replace
drop if year<77
#delimit ;

replace v_aftr=0 if vernick_shall<77 ;
replace vernick_shall=0 if vernick_shall<77 ;


gen ttt=year-76;
gen byte AK=fipsstat== 2;
gen byte AL=fipsstat== 1;
gen byte AZ=fipsstat== 4;
gen byte AR=fipsstat== 5;
gen byte CA=fipsstat== 6;
gen byte CO=fipsstat== 8;
gen byte CT=fipsstat== 9;
gen byte DC=fipsstat== 11;
gen byte DE=fipsstat== 10;
gen byte FL=fipsstat== 12;
gen byte GA=fipsstat== 13;
gen byte HI=fipsstat== 15;
gen byte IA=fipsstat== 19;
gen byte ID=fipsstat== 16;
gen byte IL=fipsstat== 17;
gen byte IN=fipsstat== 18;
gen byte KS=fipsstat== 20;
gen byte KY=fipsstat== 21;
gen byte LA=fipsstat== 22;
gen byte MA=fipsstat== 25;
gen byte MD=fipsstat== 24;
gen byte ME=fipsstat== 23;
gen byte MI=fipsstat== 26;
gen byte MN=fipsstat== 27;
gen byte MO=fipsstat== 29;
gen byte MS=fipsstat== 28;
gen byte MT=fipsstat== 30;
gen byte NC=fipsstat== 37;
gen byte ND=fipsstat== 38;
gen byte NE=fipsstat== 31;
gen byte NH=fipsstat== 33;
gen byte NJ=fipsstat== 34;
gen byte NM=fipsstat== 35;
gen byte NV=fipsstat== 32;
gen byte NY=fipsstat== 36;
gen byte OH=fipsstat== 39;
gen byte OK=fipsstat== 40;
gen byte OR=fipsstat== 41;
gen byte PA=fipsstat== 42;
gen byte RI=fipsstat== 44;
gen byte SC=fipsstat== 45;
gen byte SD=fipsstat== 46;
gen byte TN=fipsstat== 47;
gen byte TX=fipsstat== 48;
gen byte UT=fipsstat== 49;
gen byte VA=fipsstat== 51;
gen byte VT=fipsstat== 50;
gen byte WA=fipsstat== 53;
gen byte WI=fipsstat== 55;
gen byte WV=fipsstat== 54;
gen byte WY=fipsstat== 56;

gen tttAK =ttt*AK;
gen tttAL =ttt*AL;
gen tttAZ =ttt*AZ;
gen tttAR =ttt*AR;
gen tttCA =ttt*CA;
gen tttCO =ttt*CO;
gen tttCT =ttt*CT;
gen tttDC =ttt*DC;
gen tttDE =ttt*DE;
gen tttFL =ttt*FL;
gen tttGA =ttt*GA;
gen tttHI =ttt*HI;
gen tttIA =ttt*IA;
gen tttID =ttt*ID;
gen tttIL =ttt*IL;
gen tttIN =ttt*IN;
gen tttKS =ttt*KS;
gen tttKY =ttt*KY;
gen tttLA =ttt*LA;
gen tttMA =ttt*MA;
gen tttMD =ttt*MD;
gen tttME =ttt*ME;
gen tttMI =ttt*MI;
gen tttMN =ttt*MN;
gen tttMO =ttt*MO;
gen tttMS =ttt*MS;
gen tttMT =ttt*MT;
gen tttNC =ttt*NC;
gen tttND =ttt*ND;
gen tttNE =ttt*NE;
gen tttNH =ttt*NH;
gen tttNJ =ttt*NJ;
gen tttNM =ttt*NM;
gen tttNV =ttt*NV;
gen tttNY =ttt*NY;
gen tttOH =ttt*OH;
gen tttOK =ttt*OK;
gen tttOR =ttt*OR;
gen tttPA =ttt*PA;
gen tttRI =ttt*RI;
gen tttSC =ttt*SC;
gen tttSD =ttt*SD;
gen tttTN =ttt*TN;
gen tttTX =ttt*TX;
gen tttUT =ttt*UT;
gen tttVA =ttt*VA;
gen tttVT =ttt*VT;
gen tttWA =ttt*WA;
gen tttWI =ttt*WI;
gen tttWV =ttt*WV;
gen tttWY =ttt*WY;

drop ttt;

areg  lvio v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, replace noparen nolabel coefastr se 3aster;

areg  lmur v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrap v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  laga v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrob v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lpro v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  laut v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lbur v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  llar v_shall v_aftr ttt* incarc_rate densitym rpcpi rpcui rpcim stpop pb* pw* pn* iyear_78-iyear_99 [aweight=stpop], absorb(fipsstat) robust;
outreg v_shall v_aftr using Table3b.3.xls, append noparen nolabel coefastr se 3aster;


log close;


